;; Generated package description from gited.el  -*- no-byte-compile: t -*-
(define-package "gited" "0.6.0.0.20201129.50005" "Operate on Git branches like dired" '((emacs "24.4") (cl-lib "0.5")) :url "https://elpa.gnu.org/packages/gited.html" :keywords '("git" "vc" "convenience") :authors '(("Tino Calancha" . "tino.calancha@gmail.com")) :maintainer '("Tino Calancha" . "tino.calancha@gmail.com"))
